@@ -34,14 +34,11 @@ protected:
     {
         if (event->type() == QEvent::Leave) {
             Q_EMIT applicationMouseLeave();
-            return true;
-        } else if (event->type() == QEvent::Enter) {
-            Q_EMIT applicationMouseEnter();
-            return true;
-        } else {
-            // standard event processing
-            return QObject::eventFilter(obj, event);
         }
+        if (event->type() == QEvent::Enter) {
+            Q_EMIT applicationMouseEnter();
+        }
+        return QObject::eventFilter(obj, event);
     }
 };
 
@@ -83,6 +80,7 @@ public:
     Q_INVOKABLE static QString formatTime(const double time);
     Q_INVOKABLE static QString mimeType(QUrl url);
 
+    void handleSecondayInstanceMessage(const QByteArray &message);
     QCommandLineParser *parser() const;
 
     QQmlApplicationEngine *qmlEngine() const;
@@ -93,6 +91,7 @@ Q_SIGNALS:
     void qmlApplicationMouseEnter();
     void error(const QString &message);
     void saveWindowGeometryAsync(QQuickWindow *window);
+    void openUrl(const QUrl &url);
 
 private:
     explicit Application();
