@@ -18,6 +18,12 @@ ActionsModel::ActionsModel(QObject *parent)
     , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath()))
 {
     Action action;
+    action.name = QStringLiteral("openActionsDialogAction");
+    action.text = i18nc("@action", "Open Actions Dialog");
+    action.defaultShortcut = Qt::CTRL | Qt::Key_QuoteLeft; // Key_QuoteLeft =  backtick
+    action.shortcut = getShortcut(action.name, action.defaultShortcut);
+    m_actions << action;
+
     action.name = QStringLiteral("aboutHarunaAction");
     action.text = i18nc("@action", "About Haruna");
     action.iconName = QStringLiteral("haruna");
@@ -516,16 +522,18 @@ int ActionsModel::rowCount(const QModelIndex &parent) const
 {
     // For list models only the root node (an invalid parent) should return the list's size. For all
     // other (valid) parents, rowCount() should return 0 so that it does not become a tree model.
-    if (parent.isValid())
+    if (parent.isValid()) {
         return 0;
+    }
 
     return m_actions.count();
 }
 
 QVariant ActionsModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid())
+    if (!index.isValid()) {
         return QVariant();
+    }
 
     auto action = m_actions.at(index.row());
 
