@@ -95,6 +95,15 @@ QHash<int, QByteArray> PlaylistModel::roleNames() const
     return roles;
 }
 
+void PlaylistModel::clear()
+{
+    m_playlistPath = QString();
+    m_playingItem = -1;
+    beginResetModel();
+    m_playlist.clear();
+    endResetModel();
+}
+
 void PlaylistModel::addItem(const QString &path, Behaviour behaviour)
 {
     auto url = QUrl::fromUserInput(path);
@@ -107,10 +116,7 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
         return;
     }
     if (behaviour == Behaviour::Clear) {
-        m_playingItem = -1;
-        beginResetModel();
-        m_playlist.clear();
-        endResetModel();
+        clear();
     }
 
     if (url.scheme() == QStringLiteral("file")) {
@@ -123,8 +129,6 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
         }
 
         if (isVideoOrAudioMimeType(mimeType)) {
-            m_playlistPath = QString();
-
             if (behaviour == Behaviour::Clear) {
                 if (PlaylistSettings::loadSiblings()) {
                     getSiblingItems(url);
@@ -145,7 +149,6 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
             m_playlistPath = url.toString();
             getYouTubePlaylist(url, behaviour);
         } else {
-            m_playlistPath = QString();
             if (behaviour == Behaviour::Clear) {
                 appendItem(url);
                 setPlayingItem(0);
@@ -162,21 +165,20 @@ void PlaylistModel::appendItem(const QUrl &url)
     QFileInfo itemInfo(url.toLocalFile());
     auto row{m_playlist.count()};
     if (itemInfo.exists() && itemInfo.isFile()) {
-        item = {
-            .url = url,
-            .filename = itemInfo.fileName(),
-            .mediaTitle = QString(),
-            .folderPath = itemInfo.absolutePath(),
-            .duration = QString(),
-        };
+        item.url = url;
+        item.filename = itemInfo.fileName();
+        item.mediaTitle = QString();
+        item.folderPath = itemInfo.absolutePath();
+        item.duration = QString();
     } else {
         if (url.scheme().startsWith(QStringLiteral("http"))) {
-            item = {
-                .url = url,
-                .filename = url.toString(),
-            };
+            item.url = url;
+            item.filename = url.toString();
             // causes issues with lots of links
-            // getHttpItemInfo(path, row);
+            if (m_httpItemCounter < 20) {
+                getHttpItemInfo(url, row);
+                ++m_httpItemCounter;
+            }
         }
     }
 
@@ -222,13 +224,12 @@ void PlaylistModel::getSiblingItems(const QUrl &url)
     for (const auto &file : siblingFiles) {
         QFileInfo fileInfo(file);
         auto fileUrl = QUrl::fromLocalFile(file);
-        PlaylistItem item = {
-            .url = fileUrl,
-            .filename = fileInfo.fileName(),
-            .mediaTitle = QString(),
-            .folderPath = fileInfo.absolutePath(),
-            .duration = QString(),
-        };
+        PlaylistItem item;
+        item.url = fileUrl;
+        item.filename = fileInfo.fileName();
+        item.mediaTitle = QString();
+        item.folderPath = fileInfo.absolutePath();
+        item.duration = QString();
         m_playlist.append(item);
         if (url == fileUrl) {
             setPlayingItem(m_playlist.count() - 1);
@@ -305,13 +306,12 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
             auto title = entries[i][QStringLiteral("title")].toString();
             auto duration = entries[i][QStringLiteral("duration")].toDouble();
 
-            PlaylistItem item = {
-                .url = QUrl::fromUserInput(url),
-                .filename = !title.isEmpty() ? title : url,
-                .mediaTitle = !title.isEmpty() ? title : url,
-                .folderPath = QString(),
-                .duration = Application::formatTime(duration),
-            };
+            PlaylistItem item;
+            item.url = QUrl::fromUserInput(url);
+            item.filename = !title.isEmpty() ? title : url;
+            item.mediaTitle = !title.isEmpty() ? title : url;
+            item.folderPath = QString();
+            item.duration = Application::formatTime(duration);
 
             beginInsertRows(QModelIndex(), m_playlist.count(), m_playlist.count());
             m_playlist.append(item);
@@ -352,6 +352,7 @@ void PlaylistModel::getHttpItemInfo(const QUrl &url, int row)
         Q_EMIT dataChanged(index(row, 0), index(row, 0));
     });
 }
+
 bool PlaylistModel::isVideoOrAudioMimeType(const QString &mimeType)
 {
     // clang-format off
