@@ -76,6 +76,7 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     virtual QHash<int, QByteArray> roleNames() const override;
 
+    Q_INVOKABLE void clear();
     Q_INVOKABLE void addItem(const QString &path, PlaylistModel::Behaviour behaviour);
     Q_INVOKABLE void addItem(const QUrl &url, PlaylistModel::Behaviour behaviour);
 
@@ -95,6 +96,7 @@ private:
     QList<PlaylistItem> m_playlist;
     int m_playingItem{-1};
     QString m_playlistPath;
+    int m_httpItemCounter{0};
 };
 
 Q_DECLARE_METATYPE(PlaylistModel::Behaviour)
