@@ -9,7 +9,8 @@
 
 #include <QDBusAbstractAdaptor>
 
-class MpvItem;
+#include "mpvitem.h"
+
 class QDBusObjectPath;
 
 class MediaPlayer2Player : public QDBusAbstractAdaptor
@@ -77,6 +78,7 @@ Q_SIGNALS:
 
 private:
     MpvItem *m_mpv;
+    QString getThumbnail(const QString &path);
 };
 
 #endif // MEDIAPLAYER2PLAYER_H
