@@ -7,6 +7,8 @@
 #ifndef MPVABSTRACTITEM_H
 #define MPVABSTRACTITEM_H
 
+#include "mpvcontroller.h"
+
 #include <QtQuick/QQuickFramebufferObject>
 #include <mpv/client.h>
 #include <mpv/render_gl.h>
@@ -21,21 +23,22 @@ public:
     ~MpvAbstractItem();
 
     Renderer *createRenderer() const override;
-    Q_INVOKABLE void setProperty(const QString &name, const QVariant &value);
-    Q_INVOKABLE QVariant getProperty(const QString &name);
+    Q_INVOKABLE int setProperty(const QString &property, const QVariant &value);
+    Q_INVOKABLE int setPropertyAsync(const QString &property, const QVariant &value, int id = 0);
+    Q_INVOKABLE QVariant getProperty(const QString &property);
+    Q_INVOKABLE int getPropertyAsync(const QString &property, int id = 0);
     Q_INVOKABLE QVariant getCachedPropertyValue(const QString &property);
-    Q_INVOKABLE void command(const QStringList &params);
-    Q_INVOKABLE QVariant synchronousCommand(const QStringList &params);
+    Q_INVOKABLE QVariant command(const QStringList &params);
+    Q_INVOKABLE int commandAsync(const QStringList &params, int id = 0);
     Q_INVOKABLE QVariant expandText(const QString &text);
 
     friend class MpvRenderer;
 
 Q_SIGNALS:
     void ready();
-    void mpvCommand(const QStringList &params);
-    void setMpvProperty(const QString &property, const QVariant &value);
 
 protected:
+    void observeProperty(const QString &property, mpv_format format, int id = 0);
     void cachePropertyValue(const QString &property, const QVariant &value);
 
     QThread *m_workerThread{nullptr};
