@@ -48,7 +48,7 @@ private:
     double m_position{0.0};
     QString m_file;
     bool m_accuratePreview;
-    bool m_isLocalFile;
+    bool m_isLocalFile{false};
 };
 
 #endif // MPVPREVIEW_H
