@@ -22,8 +22,9 @@ static void *get_proc_address_mpv(void *ctx, const char *name)
     Q_UNUSED(ctx)
 
     QOpenGLContext *glctx = QOpenGLContext::currentContext();
-    if (!glctx)
+    if (!glctx) {
         return nullptr;
+    }
 
     return reinterpret_cast<void *>(glctx->getProcAddress(QByteArray(name)));
 }
@@ -45,7 +46,9 @@ MpvRenderer::MpvRenderer(MpvAbstractItem *new_obj)
 void MpvRenderer::render()
 {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    m_mpvAItem->window()->resetOpenGLState();
+    if (m_mpvAItem->window() != nullptr) {
+        m_mpvAItem->window()->resetOpenGLState();
+    }
 #endif
 
     QOpenGLFramebufferObject *fbo = framebufferObject();
@@ -69,7 +72,9 @@ void MpvRenderer::render()
     mpv_render_context_render(m_mpvAItem->m_mpv_gl, params);
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    m_mpvAItem->window()->resetOpenGLState();
+    if (m_mpvAItem->window() != nullptr) {
+        m_mpvAItem->window()->resetOpenGLState();
+    }
 #endif
 }
 
